pub enum LiquidKind {
Water,
Lava,
}Variants
Implementations
Sourceimpl LiquidKind
impl LiquidKind
Sourcepub fn merge(self, other: LiquidKind) -> LiquidKind
pub fn merge(self, other: LiquidKind) -> LiquidKind
If an entity is in multiple overlapping liquid blocks, which one takes precedence? (should be a rare edge case, since checkerboard patterns of water and lava shouldn’t show up in worldgen)